import doctest
import glob

try:
    import pkg_resources
    pkg_resources.require('Rtree')
except:
    pass

for file in [
    'BoundsCheck.txt',
    'R-Tree.txt',
    ]:
    doctest.testfile(file, verbose=1)

